@@ -2,16 +2,21 @@
 #                              MIT Licence (C) 2022 Cubicpath@Github                              #
 ###################################################################################################
 """Relative package containing custom GUI elements."""
+
+__all__ = (
+    'AppWindow',
+    'BetterLineEdit',
+    'FileContextMenu',
+    'GetterApp',
+    'HelpContextMenu',
+    'HistoryComboBox',
+    'LicenseViewer',
+    'SettingsWindow',
+    'Theme',
+    'ToolsContextMenu',
+)
+
 from .app import *
 from .menus import *
 from .widgets import *
 from .windows import *
-
-__all__ = (
-    'AppWindow',
-    'GetterApp',
-    'HelpContextMenu',
-    'FileContextMenu',
-    'LicenseViewer',
-    'SettingsWindow',
-)
