@@ -2,22 +2,26 @@
 #                              MIT Licence (C) 2022 Cubicpath@Github                              #
 ###################################################################################################
 """Module for the main application classes."""
-from pathlib import Path
-
-from PySide6.QtCore import *
-from PySide6.QtWidgets import *
-from toml.decoder import CommentValue
-
-from ..tomlfile import *
 
 __all__ = (
     'GetterApp',
     'Theme',
 )
 
+from collections.abc import Sequence
+from pathlib import Path
+
+from PySide6.QtCore import *
+from PySide6.QtWidgets import *
+
+from ..lang import Translator
+from ..tomlfile import *
+from ..types import CommentValue
+
 
 class Theme:
     """Object containing data about a Theme."""
+    __slots__ = ('id', 'style', 'display_name')
 
     def __init__(self, id: str, style: str = '', display_name: str | None = None) -> None:
         """Create a new Theme using a unique ID, the style data (.qss file content), and an optional display name.
@@ -31,13 +35,15 @@ class Theme:
         self.display_name: str = display_name if display_name is not None else self.id
 
 
+# TODO: Add logging functionality
 class GetterApp(QApplication):
     """The main HaloInfiniteGetter PySide application that runs in the background and manages the process."""
     _legacy_style: str = None
 
-    def __init__(self, argv: list[str], settings: TomlFile) -> None:
+    def __init__(self, argv: Sequence[str], settings: TomlFile) -> None:
         """Create a new app with the given arguments and settings."""
         super().__init__(argv)
+        self.translator:      Translator = Translator(settings['language'])
         self.settings:        TomlFile = settings
         self.themes:          dict[str, Theme] = {}  # PyCharm detects this as a dict[str, str], despite explicit type hints.
         self.theme_index_map: dict[str, int] = {}
@@ -77,10 +83,9 @@ class GetterApp(QApplication):
                 file.close()
 
         # noinspection PyUnresolvedReferences
-        self.theme_index_map = {theme_id: i for i, theme_id in enumerate(theme.id for theme in self.sorted_themes)}
+        self.theme_index_map = {theme_id: i for i, theme_id in enumerate(theme.id for theme in self.sorted_themes())}
         self.update_stylesheet()
 
-    @property
     def sorted_themes(self) -> list[Theme]:
         """List of themes sorted by their display name."""
         # noinspection PyTypeChecker
