@@ -2,42 +2,38 @@
 #                              MIT Licence (C) 2022 Cubicpath@Github                              #
 ###################################################################################################
 """Module used for TOML configurations."""
-import warnings
-from collections.abc import Callable
-from pathlib import Path
-from pathlib import PurePath
-from types import UnionType
-from typing import Any
-
-import toml
-from toml.decoder import CommentValue
-from toml.decoder import TomlDecodeError
-from toml.decoder import TomlPreserveCommentDecoder
-from toml.encoder import _dump_str
-from toml.encoder import TomlEncoder
-# noinspection PyProtectedMember
 
 __all__ = (
     'BetterTomlDecoder',
     'BetterTomlEncoder',
-    'TOML_VALUE',
+    'make_comment_val',
     'TomlFile',
 )
 
-TOML_VALUE: UnionType = dict | list | float | int | str | bool | PurePath
-"""Represents a possible TOML value, with :py:class:`dict` being a Table, and :py:class:`list` being an Array."""
+import warnings
+from collections.abc import Callable
+from pathlib import Path
+from pathlib import PurePath
+from typing import Any
+from typing import Final
 
-SPECIAL_PATH_PREFIX = '$PATH$|'
+import toml.decoder
+import toml.encoder
+
+from .types import CommentValue
+from .types import TOML_VALUE
+
+SPECIAL_PATH_PREFIX: Final[str] = '$PATH$|'
 
 # TODO: Move event_subscribers to an EventBus class
 
 
-class BetterTomlDecoder(TomlPreserveCommentDecoder):
+class BetterTomlDecoder(toml.TomlPreserveCommentDecoder):
     """Inherits the effects of :py:class:`toml.TomlPreserveCommentEncoder`.
 
     With native support for pathlib :py:class:`Path` values; not abandoning the TOML specification.
     """
-    def load_value(self, v: str, strictly_valid=True):
+    def load_value(self, v: str, strictly_valid=True) -> tuple[Any, str | bool]:
         """If the value is a string and starts with the SPECIAL_PATH_PREFIX, load the value enclosed in quotes as a :py:class:`Path`."""
         if v[1:].startswith(SPECIAL_PATH_PREFIX):
             v = Path(v[1:].removeprefix(SPECIAL_PATH_PREFIX)[:-1])
@@ -45,22 +41,23 @@ class BetterTomlDecoder(TomlPreserveCommentDecoder):
         return super().load_value(v=v, strictly_valid=strictly_valid)
 
 
-class BetterTomlEncoder(TomlEncoder):
+class BetterTomlEncoder(toml.TomlEncoder):
     """Combines both the effects of :py:class:`toml.TomlPreserveCommentEncoder` and of :py:class:`toml.TomlPathlibEncoder`.
 
     Has native support for pathlib :py:class:`PurePath`; not abandoning the TOML specification.
     """
-    def __init__(self, _dict=dict, preserve=False):
+    def __init__(self, _dict=dict, preserve=False) -> None:
         super().__init__(_dict, preserve)
         self.dump_funcs[CommentValue] = lambda comment_val: comment_val.dump(self.dump_value)
         self.dump_funcs[PurePath] = self._dump_pathlib_path
 
     @staticmethod
-    def _dump_pathlib_path(v: PurePath):
+    def _dump_pathlib_path(v: PurePath) -> str:
         """Translate :py:class:`PurePath` to string and dump."""
-        return _dump_str(str(v))
+        # noinspection PyProtectedMember
+        return toml.encoder._dump_str(str(v))
 
-    def dump_value(self, v: TOML_VALUE):
+    def dump_value(self, v: TOML_VALUE) -> str:
         """Support :py:class:`Path` decoding by prefixing a :py:class:`PurePath` string with a special marker."""
         if isinstance(v, PurePath):
             if isinstance(v, Path):
@@ -145,7 +142,7 @@ class TomlFile:
 
         :param key: Key to get value from.
         """
-        scope, path = self._search_scope(key, 'get')
+        scope, path = self._search_scope(key, mode='get')
 
         for sub in self._event_subscribers.get(f'$get:{key}', []):
             sub[0](*sub[1], **sub[2])
@@ -222,7 +219,7 @@ class TomlFile:
                     else:
                         self._data = toml_data
 
-            except (LookupError, OSError, TomlDecodeError):
+            except (LookupError, OSError, toml.TomlDecodeError):
                 pass  # Pass to end of function, to fail.
 
             else:
@@ -244,3 +241,8 @@ class TomlFile:
         subscribers = self._event_subscribers.get(key, [])
         subscribers.append((f, args, kwargs))
         self._event_subscribers[key] = subscribers
+
+
+def make_comment_val(val: TOML_VALUE, comment: str, new_line=False) -> CommentValue:
+    """Build and return :py:class:`CommentValue`."""
+    return CommentValue(val=val, comment=f'# {comment}', beginline=new_line, _dict=dict)
